import typescript from "@rollup/plugin-typescript";
import commonjs from "@rollup/plugin-commonjs";
import external from "rollup-plugin-peer-deps-external";
import { camelCase } from "lodash";
import { uglify } from "rollup-plugin-uglify";
import resolve from "@rollup/plugin-node-resolve";
import pkg from "./package.json";
import bundleSize from "rollup-plugin-bundle-size";
import copy from "rollup-plugin-copy";

const globals = {};

const libraryName = "unom-style";

export default {
  input: `src/${libraryName}.ts`,
  output: [
    {
      file: pkg.main,
      name: camelCase(libraryName),
      format: "umd",
      globals: globals,
      sourcemap: true,
    },
    {
      file: pkg.module,
      format: "es",
      exports: "named",
      globals: globals,
      sourcemap: true,
    },
  ],
  plugins: [
    copy({
      targets: [
        { src: "static/easings.css", dest: "build/easings/easings.css" },
      ],
    }),
    external(),
    resolve(),
    typescript({
      tsconfig: "./tsconfig.json",
    }),
    uglify(),
    bundleSize(),
    commonjs({
      include: ["node_modules/**"],
    }),
  ],
};
