import {
  generateThemeOverride,
  generateThemeRoot,
  generateTheme,
  ThemeInput,
} from ".";

const exampleProperties = {
  "color-main-10": "black",
  "color-main-50": "grey",
};

const exampleThemes: ThemeInput[] = [
  {
    name: "default",
    colors: { "color-main": "black" },
  },
  {
    name: "dark",
    colors: { "color-main": "white", "color-secondary": "blue" },
  },
  { name: "light", colors: { "color-secondary": "grey" } },
];

test("it generates css based on input properties", () => {
  const themeClass = generateThemeOverride({
    properties: exampleProperties,
    selector: ".dark-theme",
  });

  expect(themeClass).toBeDefined();
});

test("no input so it returns empty string", () => {
  const themeClass = generateThemeOverride({
    properties: {},
    selector: ".dark-theme",
  });

  expect(themeClass).toBeDefined();
  expect(themeClass).toEqual("");
});

test("it generates the theme root", () => {
  const themeRoot = generateThemeRoot({ properties: exampleProperties });
  console.log(themeRoot);
  expect(themeRoot).toBeDefined();
});

test("it generates the complete theme with overrides", () => {
  const theme = generateTheme({
    themes: exampleThemes,
    output: "CSS",
  });

  console.log(theme);

  expect(theme).toBeDefined();
});

test("it generates the complete theme with overrides and color shades", () => {
  const theme = generateTheme({
    themes: exampleThemes,
    output: "CSS",
    generateColorShades: {
      structure: "flat",
      format: "css-variable",
    },
  });

  console.log(theme);

  expect(theme).toBeDefined();
});
